@@ -37,13 +37,13 @@ var (
 
 // Options defines options for the logger.
 type Options struct {
-	Level               logg.Level
-	Stdout              io.Writer
-	Stderr              io.Writer
-	Distinct            bool
-	StoreErrors         bool
-	HandlerPost         func(e *logg.Entry) error
-	SuppresssStatements map[string]bool
+	Level              logg.Level
+	Stdout             io.Writer
+	Stderr             io.Writer
+	Distinct           bool
+	StoreErrors        bool
+	HandlerPost        func(e *logg.Entry) error
+	SuppressStatements map[string]bool
 }
 
 // New creates a new logger with the given options.
@@ -97,8 +97,8 @@ func New(opts Options) Logger {
 		logHandler = newStopHandler(logOnce, logHandler)
 	}
 
-	if opts.SuppresssStatements != nil && len(opts.SuppresssStatements) > 0 {
-		logHandler = newStopHandler(newSuppressStatementsHandler(opts.SuppresssStatements), logHandler)
+	if opts.SuppressStatements != nil && len(opts.SuppressStatements) > 0 {
+		logHandler = newStopHandler(newSuppressStatementsHandler(opts.SuppressStatements), logHandler)
 	}
 
 	logger := logg.New(
