@@ -56,6 +56,7 @@ type Site interface {
 	Home() Page
 
 	// Returns true if we're running in a server.
+	// Deprecated: use hugo.IsServer instead
 	IsServer() bool
 
 	// Returns the server port.
@@ -81,7 +82,7 @@ type Site interface {
 	Hugo() hugo.HugoInfo
 
 	// Returns the BaseURL for this Site.
-	BaseURL() template.URL
+	BaseURL() string
 
 	// Returns a taxonomy map.
 	Taxonomies() TaxonomyList
@@ -171,10 +172,12 @@ func (s *siteWrapper) Social() map[string]string {
 func (s *siteWrapper) Author() map[string]interface{} {
 	return s.s.Author()
 }
+
 func (s *siteWrapper) Authors() AuthorList {
 	return AuthorList{}
 }
 
+// Deprecated: Use .Site.Config.Services.GoogleAnalytics.ID instead
 func (s *siteWrapper) GoogleAnalytics() string {
 	return s.s.GoogleAnalytics()
 }
@@ -211,6 +214,7 @@ func (s *siteWrapper) Home() Page {
 	return s.s.Home()
 }
 
+// Deprecated: use hugo.IsServer instead
 func (s *siteWrapper) IsServer() bool {
 	return s.s.IsServer()
 }
@@ -247,7 +251,7 @@ func (s *siteWrapper) Hugo() hugo.HugoInfo {
 	return s.s.Hugo()
 }
 
-func (s *siteWrapper) BaseURL() template.URL {
+func (s *siteWrapper) BaseURL() string {
 	return s.s.BaseURL()
 }
 
@@ -295,6 +299,7 @@ func (s *siteWrapper) IsMultiLingual() bool {
 	return s.s.IsMultiLingual()
 }
 
+// Deprecated: Use .Site.Config.Services.Disqus.Shortname instead
 func (s *siteWrapper) DisqusShortname() string {
 	return s.s.DisqusShortname()
 }
@@ -315,6 +320,7 @@ type testSite struct {
 func (s testSite) Author() map[string]interface{} {
 	return nil
 }
+
 func (s testSite) Authors() AuthorList {
 	return AuthorList{}
 }
@@ -371,6 +377,7 @@ func (t testSite) Languages() langs.Languages {
 	return nil
 }
 
+// Deprecated: Use .Site.Config.Services.GoogleAnalytics.ID instead
 func (t testSite) GoogleAnalytics() string {
 	return ""
 }
@@ -383,6 +390,7 @@ func (t testSite) GetIdentity() identity.Identity {
 	return identity.KeyValueIdentity{Key: "site", Value: t.l.Lang}
 }
 
+// Deprecated: use hugo.IsServer instead
 func (t testSite) IsServer() bool {
 	return false
 }
@@ -415,7 +423,7 @@ func (t testSite) Taxonomies() TaxonomyList {
 	return nil
 }
 
-func (t testSite) BaseURL() template.URL {
+func (t testSite) BaseURL() string {
 	return ""
 }
 
@@ -435,6 +443,7 @@ func (testSite) GetPageWithTemplateInfo(info tpl.Info, ref ...string) (Page, err
 	return nil, nil
 }
 
+// Deprecated: Use .Site.Config.Services.Disqus.Shortname instead
 func (testSite) DisqusShortname() string {
 	return ""
 }
