@@ -216,18 +216,13 @@ const (
 	//   disallowed. Avoid using "html" and "urlquery" entirely in new templates.
 	ErrPredefinedEscaper
 
-	// errJSTmplLit: "... appears in a JS template literal"
+	// ErrJSTemplate: "... appears in a JS template literal"
 	// Example:
-	//     <script>var tmpl = `{{.Interp}`</script>
+	//     <script>var tmpl = `{{.Interp}}`</script>
 	// Discussion:
 	//   Package html/template does not support actions inside of JS template
 	//   literals.
-	//
-	// TODO(rolandshoemaker): we cannot add this as an exported error in a minor
-	// release, since it is backwards incompatible with the other minor
-	// releases. As such we need to leave it unexported, and then we'll add it
-	// in the next major release.
-	errJSTmplLit
+	ErrJSTemplate
 )
 
 func (e *Error) Error() string {
